"""This package is for compatibility with v0.1.8 and below,v0.3.0 and above will be removed. """
import logging

logging.warning(
    "The `fastapi_amis_admin.amis_admin` package is deprecated, " "please migrate to the `fastapi_amis_admin.admin` package"
)
